pub struct ListTargetsByRuleInput {
pub rule: String,
pub event_bus_name: Option<String>,
pub next_token: Option<String>,
pub limit: Option<i32>,
}Expand description
Input for the ListTargetsByRule operation.
Fields
rule: StringThe name of the rule whose targets to list.
event_bus_name: Option<String>The name of the event bus associated with the rule.
next_token: Option<String>The token for the next set of results.
limit: Option<i32>The maximum number of results to return.