pub struct PutTargetsInput {
pub rule: String,
pub targets: Vec<Target>,
pub event_bus_name: Option<String>,
}Expand description
Input for the PutTargets operation.
Fields
rule: StringThe name of the rule to add targets to.
targets: Vec<Target>The targets to add to the rule.
event_bus_name: Option<String>The name of the event bus associated with the rule.