pub struct RemoveTargetsInput {
pub rule: String,
pub ids: Vec<String>,
pub event_bus_name: Option<String>,
pub force: Option<bool>,
}Expand description
Input for the RemoveTargets operation.
Fields
rule: StringThe name of the rule to remove targets from.
ids: Vec<String>The IDs of the targets to remove.
event_bus_name: Option<String>The name of the event bus associated with the rule.
force: Option<bool>Whether to force-remove targets from a managed rule.