pub struct ListRuleNamesByTargetOutput {
pub rule_names: Vec<String>,
pub next_token: Option<String>,
}Expand description
Output for the ListRuleNamesByTarget operation.
Fields
rule_names: Vec<String>The names of the rules that reference the specified target.
next_token: Option<String>The token for the next page of results, if any.