pub struct PutEventsResultEntry {
pub event_id: Option<String>,
pub error_code: Option<String>,
pub error_message: Option<String>,
}Expand description
An entry in a PutEvents response.
Fields
event_id: Option<String>The ID of the event that was successfully submitted.
error_code: Option<String>The error code if the event was not submitted.
error_message: Option<String>The error message if the event was not submitted.